@@ -3,14 +3,14 @@
 
 """
    @project: HSPyLib
-   @package: main.modules.qt.promotions
+   @package: hspylib.main.hspylib.modules.qt.promotions
       @file: hcombobox.py
    @created: Wed, 30 Jun 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2021, HSPyLib team
+   Copyright 2022, HSPyLib team
 """
 
 from PyQt5.QtWidgets import QComboBox
